/*
 * @Copyright 2010, MechSoft 
 * MechSoft, Mechanical and Software Solutions 
 * 
 * Licensed under the Apache License, Version 2.0 (the 
 * "License"); you may not use this file except in compliance 
 * with the License. You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.defne.jpa;

import javax.persistence.EntityManager;

import org.defne.jpa.impl.ServiceBagEnitityManagerProvider;
import org.defne.service.IMessageConstants;
import org.defne.service.Message;
import org.defne.utility.Assertions;

public final class EntityManagerUtil
{
    private EntityManagerUtil()
    {
        throw new UnsupportedOperationException();
    }
    
    public static void alreadySetEntityManager(Message bag)
    {
        Assertions.checkForNullParameter(bag, "bag");
        bag.putMessageParameter(IMessageConstants.SERVICE_CALLER_NEW_ENTITY_MANAGER_KEY , false);
    }
    
    public static EntityManager getEntityManagerFromBag(Message bag)
    {
        ServiceBagEnitityManagerProvider provider = bag.getMessageParameter(ServiceBagEnitityManagerProvider.class, 
                IMessageConstants.SERVICE_CALLER_ENTITY_MANAGER_KEY);
        
        if(provider != null)
        {
            return provider.getEntityManager();
        }
        
        return null;
    }
    
    public static void putEntityManagerToBag(Message bag, EntityManager manager)
    {
        Assertions.checkForNullParameter(bag, "bag");
        Assertions.checkForNullParameter(manager, "manager");
        
        ServiceBagEnitityManagerProvider provider = new ServiceBagEnitityManagerProvider(manager);
        bag.putMessageParameter(IMessageConstants.SERVICE_CALLER_ENTITY_MANAGER_KEY, provider);
        
    }
}
