/*
 * @Copyright 2010, MechSoft 
 * MechSoft, Mechanical and Software Solutions 
 * 
 * Licensed under the Apache License, Version 2.0 (the 
 * "License"); you may not use this file except in compliance 
 * with the License. You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.defne.jpa.impl;

import java.util.Map;
import java.util.Set;
import java.util.concurrent.CopyOnWriteArraySet;

import javax.persistence.EntityManagerFactory;
import javax.persistence.Persistence;

import org.defne.jpa.api.EmfProvider;
import org.defne.utility.Assertions;
import org.defne.utility.log.ILogger;
import org.defne.utility.log.LoggerProvider;

public class DefaultEmfProvider implements EmfProvider
{
    private static final ILogger logger = LoggerProvider.getLogProvider(DefaultEmfProvider.class); 
    
    private final Set<EmfModel> emfs = new CopyOnWriteArraySet<EmfModel>();

    public DefaultEmfProvider()
    {
        
    }
    
    @Override
    public EntityManagerFactory getEntityManagerFactory(String unitName ,Map<String, String> properties)
    {
        Assertions.checkForNull(unitName, "unitName parameter is null");

        EntityManagerFactory result = null;        
        if(logger.isTraceEnabled())
        {
            logger.trace("Requesting EntityManagerFactory with unit name [" + unitName + "] and properties [" + properties);   
        }
        
        for(EmfModel emfModel : this.emfs)
        {
           if(emfModel.getUnitName().equals(unitName))
           {
               result = emfModel.getEmf();
               break;
           }
        }

        
        if(result == null)
        {
            EntityManagerFactory factory = Persistence.createEntityManagerFactory(unitName, properties);
            if(factory == null)
            {
                logger.warn("EntityManagerFactory with unitName[" + unitName + "]" + " not found");
            }
            else
            {
                result = factory;
                
                EmfModel model = new EmfModel(unitName, result);
                this.emfs.add(model);
            }
        }
 
        
        if(result == null)
        {
            if(logger.isTraceEnabled())
            {
                logger.trace("EntityManagerFactory with " +"unit name " + "[" + unitName + "] not found");
            }
        }
        
        return result;
    }

    @Override
    public EntityManagerFactory getEntityManagerFactory(String unitName)
    {
        return getEntityManagerFactory(unitName, null);
    }

    @Override
    public void removeEntityManagerFactories()
    {
        this.emfs.clear();
    }

}
