/*
 * @Copyright 2010, MechSoft 
 * MechSoft, Mechanical and Software Solutions 
 * 
 * Licensed under the Apache License, Version 2.0 (the 
 * "License"); you may not use this file except in compliance 
 * with the License. You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.defne.jpa.impl;

import javax.persistence.EntityManagerFactory;

class EmfModel
{
    private final String unitName;
    
    private final EntityManagerFactory emf;
    
    EmfModel(final String unitName, final EntityManagerFactory emf)
    {
        this.unitName = unitName;
        this.emf = emf;
    }

    /**
     * @return the unitName
     */
    protected String getUnitName()
    {
        return unitName;
    }

    /**
     * @return the emf
     */
    protected EntityManagerFactory getEmf()
    {
        return emf;
    }
    
    @Override
    public String toString()
    {
        StringBuilder builder = new StringBuilder();
        builder.append("EntityManager factory with unit name [");
        builder.append(this.unitName);
        builder.append("]");
        
        return builder.toString();
    }

    /* (non-Javadoc)
     * @see java.lang.Object#hashCode()
     */
    @Override
    public int hashCode()
    {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((unitName == null) ? 0 : unitName.hashCode());
        return result;
    }

    /* (non-Javadoc)
     * @see java.lang.Object#equals(java.lang.Object)
     */
    @Override
    public boolean equals(Object obj)
    {
        if (this == obj)
            return true;
        if (obj == null)
            return false;
        if (getClass() != obj.getClass())
            return false;
        EmfModel other = (EmfModel) obj;
        if (unitName == null)
        {
            if (other.unitName != null)
                return false;
        }
        else if (!unitName.equals(other.unitName))
            return false;
        return true;
    }

    
    
}
